#ifndef _BSS_1D_CODE_READER_H_
#define _BSS_1D_CODE_READER_H_


/*
// Import/Export support
*/

#if defined(_MSC_VER) && defined(_BSS_1D_DLL)
#if defined(_BSS_1D_EXPORTS)
#define BSS_DLL __declspec(dllexport)
#else
#define BSS_DLL __declspec(dllimport)
#endif
#else
#define BSS_DLL
#endif

#ifdef __cplusplus
extern "C" {
#endif


/*
// Definitions of return codes 
*/

#define BSS_1D_OK               (0)
#define BSS_1D_NOTFOUND         (1)
#define BSS_1D_INVALIDARGS      (2)
#define BSS_1D_OUTOFMEMORY      (3)
#define BSS_1D_BADSYMBOL        (4)


/* 
// Structure for general barcode information
*/
typedef struct BSS_1DCodeInfo_Struct
{
    int                 nCenterPosX;           /* Center (X) barcode position on the image    */
    int                 nCenterPosY;           /* Center (Y) barcode position on the image    */
    int                 nDataLength;           /* Length of barcode's data (in bytes)         */
    char*               pchData;               /* Pointer to barcode's data                   */
} bss1DCodeInfo;


/* 
// Read 1DCode barcode symbol on the image
*/
BSS_DLL int BSS_Read1DCode
(
    const unsigned char* pImageData,           /* Pointer to image data                       */
    int                  nImageWidth,          /* The image width                             */
    int                  nImageHeight,         /* The image height                            */
    int                  nImageRowDist,        /* Distance between image's rows (in bytes)    */
    int                  nTryReadMultiple,     /* Try to read multiple barcodes on the image  */
    bss1DCodeInfo**      pp1DCodeInfo,         /* Pointer to array with barcodes' information */
    int*                 pn1DCodeInfoCount     /* Pointer to number of recognized symbol(s)   */
);

/* 
// Release allocated resources 
*/
BSS_DLL int BSS_Release1DCodeResults
(
    bss1DCodeInfo*   p1DCodeInfo,             /* Pointer to array with barcodes' information */
    int              n1DCodeInfoCount         /* Number of items in the array                */
);

#ifdef __cplusplus
}       /* extern "C" */
#endif

#endif /* _BSS_1D_CODE_READER_H_ */
